@@ -78,6 +78,7 @@ struct tok {
     const char *s;		/* string */
 };
 
+#if 0
 static const struct tok ethertype_values[] = { 
     { ETHERTYPE_IP,		"IPv4" },
     { ETHERTYPE_MPLS,		"MPLS unicast" },
@@ -115,6 +116,7 @@ static const struct tok ethertype_values[] = {
     { ETHERTYPE_GRE_ISO,        "GRE-OSI" },
     { 0, NULL}
 };
+#endif
 
 /*max length of an IEEE 802.11 packet*/
 #ifndef MAX_LEN_80211
@@ -1735,7 +1737,12 @@ void Wifipcap::handle_packet_callback(u_char *user, const struct pcap_pkthdr *he
 const char *Wifipcap::SetFilter(const char *filter)
 {
     struct bpf_program fp;
+#ifdef PCAP_NETMASK_UNKNOWN
     bpf_u_int32 netp=PCAP_NETMASK_UNKNOWN;
+#else
+    bpf_u_int32 netp=0;
+#endif
+
 
     if(pcap_compile(descr,&fp,(char *)filter,0,netp) == -1) { 
 	return "Error calling pcap_compile"; 
